@@ -1,18 +1,27 @@
 from pytest import raises, mark
 import sqlalchemy as sa
+passlib = None
+try:
+    import passlib
+except ImportError:
+    pass
 from wtforms.fields import (
     TextField,
     TextAreaField,
     BooleanField,
     FloatField,
+    PasswordField,
 )
 from wtforms.validators import Length
 from sqlalchemy_utils import (
     ColorType,
-    PhoneNumberType,
+    EmailType,
     NumberRangeType,
-    EmailType
+    PasswordType,
+    PhoneNumberType,
+    UUIDType
 )
+from sqlalchemy_utils.types import arrow
 from sqlalchemy_utils.types import phone_number
 from wtforms_components import (
     ColorField,
@@ -179,6 +188,20 @@ class TestModelColumnToFormFieldTypeConversion(ModelFormTestCase):
         self.init(type_=NumberRangeType)
         self.assert_type('test_column', NumberRangeField)
 
+    @mark.xfail('passlib is None')
+    def test_password_type_converts_to_password_field(self):
+        self.init(type_=PasswordType)
+        self.assert_type('test_column', PasswordField)
+
+    @mark.xfail('arrow.arrow is None')
+    def test_arrow_type_converts_to_datetime_field(self):
+        self.init(type_=arrow.ArrowType)
+        self.assert_type('test_column', DateTimeField)
+
+    def test_uuid_type_converst_to_uuid_type(self):
+        self.init(type_=UUIDType)
+        self.assert_type('test_column', TextField)
+
     def test_color_type_converts_to_color_field(self):
         self.init(type_=ColorType)
         self.assert_type('test_column', ColorField)
