@@ -1,10 +1,12 @@
 #import pytz
 from collections import OrderedDict
+from decimal import Decimal
 from wtforms import (
     BooleanField,
     FloatField,
     TextAreaField,
     TextField,
+    PasswordField,
 )
 from wtforms.validators import (
     DataRequired,
@@ -28,8 +30,10 @@ from wtforms_components import (
     PhoneNumberField,
     SelectField,
     TimeField,
+    TimeRange,
     Unique,
 )
+from wtforms_components.widgets import NumberInput
 from .exc import InvalidAttributeException, UnknownTypeException
 from .utils import (
     is_date_column,
@@ -64,10 +68,20 @@ class FormGenerator(object):
         (sa.types.String, TextField),
         (sa.types.Time, TimeField),
         (sa.types.Unicode, TextField),
+        (types.ArrowType, DateTimeField),
+        (types.ColorType, ColorField),
         (types.EmailType, EmailField),
         (types.NumberRangeType, NumberRangeField),
+        (types.PasswordType, PasswordField),
         (types.PhoneNumberType, PhoneNumberField),
-        (types.ColorType, ColorField),
+        (types.ScalarListType, TextField),
+        (types.UUIDType, TextField),
+    ))
+
+    WIDGET_MAP = OrderedDict((
+        (DecimalField, NumberInput),
+        (FloatField, NumberInput),
+        (IntegerField, NumberInput),
     ))
 
     def __init__(self, form_class):
@@ -300,8 +314,34 @@ class FormGenerator(object):
 
         if hasattr(column.type, 'country_code'):
             kwargs['country_code'] = column.type.country_code
+
+        kwargs['widget'] = self.widget(column)
         return kwargs
 
+    def widget(self, column):
+        widget = column.info.get('widget', None)
+        if widget is not None:
+            return widget
+
+        kwargs = {}
+
+        step = column.info.get('step', None)
+        if step is not None:
+            kwargs['step'] = step
+        else:
+            if isinstance(column.type, sa.types.Numeric):
+                if column.type.scale is not None:
+                    kwargs['step'] = self.scale_to_step(column.type.scale)
+
+        if kwargs:
+            widget_class = self.WIDGET_MAP[
+                self.get_field_class(column)
+            ]
+            return widget_class(**kwargs)
+
+    def scale_to_step(self, scale):
+        return str(pow(Decimal('0.1'), scale))
+
     def type_agnostic_parameters(self, column):
         """
         Returns all type agnostic form field parameters for given column.
@@ -312,7 +352,6 @@ class FormGenerator(object):
         kwargs = {}
         kwargs['description'] = column.info.get('description', '')
         kwargs['label'] = column.info.get('label', name)
-        kwargs['widget'] = column.info.get('widget', None)
         return kwargs
 
     def select_field_kwargs(self, column):
@@ -418,6 +457,8 @@ class FormGenerator(object):
                 return NumberRange(min=min_, max=max_)
             elif is_date_column(column):
                 return DateRange(min=min_, max=max_)
+            elif isinstance(column.type, sa.types.Time):
+                return TimeRange(min=min_, max=max_)
 
     def length_validator(self, column):
         """
@@ -442,8 +483,10 @@ class FormGenerator(object):
             return column.info['form_field_class']
         if 'choices' in column.info and column.info['choices']:
             return SelectField
-        if type(column.type) not in self.TYPE_MAP and \
-           isinstance(column.type, sa.types.TypeDecorator):
+        if (
+            type(column.type) not in self.TYPE_MAP and
+            isinstance(column.type, sa.types.TypeDecorator)
+        ):
             check_type = column.type.impl
         else:
             check_type = column.type
